slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSEVSLGetDamping

Gets the type of damping.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSEVSLGetDamping(EPS eps,EPSEVSLDamping *damping)

Not Collective

### Input Parameter

| eps | - the eigensolver context

### Output Parameter

| damping | - the type of damping

### See Also

EPSEVSLSetDamping()

### Level

intermediate

### Location

src/eps/impls/external/evsl/evsl.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages